aboutsummaryrefslogtreecommitdiffstats
path: root/DynamicColumn.h
diff options
context:
space:
mode:
authorDaniel Lange <DLange@git.local>2024-01-10 11:17:08 +0100
committerDaniel Lange <DLange@git.local>2024-01-10 11:17:08 +0100
commite7372d18a1a661d8c3dba9f51e1f17b5f94171a7 (patch)
treee8270dd60ec096bee8157dbadf029e15ed584592 /DynamicColumn.h
parent937052b231259a47d881d539ad5748245ef55b99 (diff)
downloaddebian_htop-e7372d18a1a661d8c3dba9f51e1f17b5f94171a7.tar.gz
debian_htop-e7372d18a1a661d8c3dba9f51e1f17b5f94171a7.tar.bz2
debian_htop-e7372d18a1a661d8c3dba9f51e1f17b5f94171a7.zip
New upstream version 3.3.0
Diffstat (limited to 'DynamicColumn.h')
-rw-r--r--DynamicColumn.h25
1 files changed, 18 insertions, 7 deletions
diff --git a/DynamicColumn.h b/DynamicColumn.h
index 4760e6e..bdce82d 100644
--- a/DynamicColumn.h
+++ b/DynamicColumn.h
@@ -1,29 +1,40 @@
#ifndef HEADER_DynamicColumn
#define HEADER_DynamicColumn
+/*
+htop - DynamicColumn.h
+(C) 2023 htop dev team
+Released under the GNU GPLv2+, see the COPYING file
+in the source distribution for its full text.
+*/
#include <stdbool.h>
#include "Hashtable.h"
#include "Process.h"
#include "RichString.h"
+#include "Table.h"
-#define DYNAMIC_MAX_COLUMN_WIDTH 28
+#define DYNAMIC_MAX_COLUMN_WIDTH 64
#define DYNAMIC_DEFAULT_COLUMN_WIDTH -5
typedef struct DynamicColumn_ {
- char name[32]; /* unique, internal-only name */
- char* heading; /* displayed in main screen */
- char* caption; /* displayed in setup menu (short name) */
- char* description; /* displayed in setup menu (detail) */
- int width; /* display width +/- for value alignment */
+ char name[32]; /* unique, internal-only name */
+ char* heading; /* displayed in main screen */
+ char* caption; /* displayed in setup menu (short name) */
+ char* description; /* displayed in setup menu (detail) */
+ int width; /* display width +/- for value alignment */
+ bool enabled; /* false == ignore this column (until enabled) */
+ Table* table; /* pointer to DynamicScreen or ProcessTable */
} DynamicColumn;
Hashtable* DynamicColumns_new(void);
void DynamicColumns_delete(Hashtable* dynamics);
-const char* DynamicColumn_init(unsigned int key);
+const char* DynamicColumn_name(unsigned int key);
+
+void DynamicColumn_done(DynamicColumn* this);
const DynamicColumn* DynamicColumn_lookup(Hashtable* dynamics, unsigned int key);

© 2014-2024 Faster IT GmbH | imprint | privacy policy